#!/bin/sh
UPDATE_SCRIPT=/usr/share/awstats/tools/update.sh
if [ -x $UPDATE_SCRIPT ]
then
  su -s /bin/sh -l -c $UPDATE_SCRIPT www-data
fi
